summaryrefslogtreecommitdiff
path: root/include/my_getopt.h
diff options
context:
space:
mode:
authorjani@hynda.mysql.fi <>2002-01-30 05:08:17 +0200
committerjani@hynda.mysql.fi <>2002-01-30 05:08:17 +0200
commit784e1d8b347429c3b60c9ae9846035d8ea5c7121 (patch)
tree4d86999d0c0547ac87829b227add5c4743ace08c /include/my_getopt.h
parent2c24b6fb9e82869bc6b0e677fcf67253421b1ba1 (diff)
downloadmariadb-git-784e1d8b347429c3b60c9ae9846035d8ea5c7121.tar.gz
New functionality to my_getopt. myisamchk now uses my_getopt
only.
Diffstat (limited to 'include/my_getopt.h')
-rw-r--r--include/my_getopt.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/my_getopt.h b/include/my_getopt.h
index fef8aacd75a..8321ad4cd1c 100644
--- a/include/my_getopt.h
+++ b/include/my_getopt.h
@@ -23,14 +23,15 @@ struct my_optarg
};
-enum get_opt_var_type { GET_NO_ARG, GET_INT, GET_LL, GET_STR };
+enum get_opt_var_type { GET_NO_ARG, GET_LONG, GET_LL, GET_STR };
enum get_opt_arg_type { NO_ARG, OPT_ARG, REQUIRED_ARG };
struct my_option
{
const char *name; /* Name of the option */
const char *comment; /* option comment, for autom. --help */
- char *value; /* The variable value */
+ gptr *value; /* The variable value */
+ gptr *u_max_value; /* The user def. max variable value */
const char **str_values; /* Pointer to possible values */
enum get_opt_var_type var_type;
enum get_opt_arg_type arg_type;
@@ -41,6 +42,6 @@ struct my_option
longlong sub_size; /* Subtract this from given value */
long block_size; /* Value should be a mult. of this */
int app_type; /* To be used by an application */
- my_bool changeable_var; /* If true, the option is a variable */
+ my_bool opt_is_var; /* If true, the option is a variable */
};